@@ -3,7 +3,7 @@ BEGIN {
   $Syccess::Error::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Syccess error message
-$Syccess::Error::VERSION = '0.005';
+$Syccess::Error::VERSION = '0.006';
 use Moo;
 
 with qw(
@@ -58,7 +58,30 @@ Syccess::Error - Syccess error message
 
 =head1 VERSION
 
-version 0.005
+version 0.006
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+=encoding utf8
+
+=head1 SUPPORT
+
+IRC
+
+  Join #sycontent on irc.perl.org. Highlight Getty for fast reaction :).
+
+Repository
+
+  http://github.com/SyContent/Syccess
+  Pull request and additional contributors are welcome
+
+Issue Tracker
+
+  http://github.com/SyContent/Syccess/issues
+
+=cut
 
 =head1 AUTHOR
 
