@@ -3,7 +3,7 @@ BEGIN {
   $Syccess::Field::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Syccess field
-$Syccess::Field::VERSION = '0.005';
+$Syccess::Field::VERSION = '0.006';
 use Moo;
 use Module::Runtime qw( use_module );
 use Module::Load::Conditional qw( can_load );
@@ -132,7 +132,30 @@ Syccess::Field - Syccess field
 
 =head1 VERSION
 
-version 0.005
+version 0.006
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+=encoding utf8
+
+=head1 SUPPORT
+
+IRC
+
+  Join #sycontent on irc.perl.org. Highlight Getty for fast reaction :).
+
+Repository
+
+  http://github.com/SyContent/Syccess
+  Pull request and additional contributors are welcome
+
+Issue Tracker
+
+  http://github.com/SyContent/Syccess/issues
+
+=cut
 
 =head1 AUTHOR
 
